==> nsc-2.0.6-132-GA.update.tgz: var/webconfig/SAFe/application/views/safe_texteditor.php <==
<?php
/** vim: set tabstop=4 softtabstop=4 shiftwidth=4 textwidth=80 smarttab expandtab: **/
/** coding: utf-8: **/
/*
 * Copyright (C) 2012  Sangoma Technologies Corp.
 * All Rights Reserved.
 *
 * Author(s)
 * your name <your_name@sangoma.com>
 *
 * This code is Sangoma Technologies Confidential Property.
 * Use of and access to this code is covered by a previously executed
 * non-disclosure agreement between Sangoma Technologies and the Recipient.
 * This code is being supplied for evaluation purposes only and is not to be
 * used for any other purpose.
*/
?>
<!-- CodeMirror CSS-->
<link rel="stylesheet" href="/SAFe/js/codemirror/lib/codemirror.css">
<!-- CodeMirror theme -->

<!-- CodeMirror extra CSS -->
<link rel="stylesheet" href="/SAFe/js/codemirror/mode/diff/diff.css">
<link rel="stylesheet" href="/SAFe/js/codemirror/mode/markdown/markdown.css">
<link rel="stylesheet" href="/SAFe/js/codemirror/mode/tiddlywiki/tiddlywiki.css">
<!-- CodeMirror itself -->
<script src="/SAFe/js/codemirror/lib/codemirror.js" type="text/javascript"></script>
<script src="/SAFe/js/jquery/jquery.base64.js" type="text/javascript"></script>
<!-- CodeMirror Modes -->
<?php
if (!isset($height)) $height = "500px";
if (!isset($width)) $width = "100%";
if (!isset($min_height)) $min_height = $height;
if (isset($text_mode)) {
?>
  <script src="/SAFe/js/codemirror/mode/<?php
    echo $text_mode ?>/<?php
    echo $text_mode ?>.js" type="text/javascript"></script>
<?php
}
?>
  <?php
echo safe_webtabletitleopen($table_title, '100%', '') ?>
  <tr>
    <td>
    <div id="#editorContainer" style="width:<?php
echo $width
?>; display: inline-block; border: 1px solid black;">
    <div style="display:inline-block; width:<?php
echo $width
?>; min-height:<?php
echo $min_height
?>;">
          <textarea class="editorWidth" id="editorTextArea" name="editor" style="display:none;"><?php
echo $editor_data
?></textarea> 
        </div>
      </div>
    </td>
  </tr>
  <tr>
    <td class='mytablelegend' colspan='%s' align='center'>
<?php
if (isset($url_save)) { ?>
      <input id="editorSaveButton" value="Save" type="button" name='save' class="ui-state-default ui-corner-all">
<?php
}
if (isset($url_cancel)) { ?>
      <input id="cancel_editor" value="Cancel" type="button" name='cancel' class="ui-state-default ui-corner-all" onclick="window.location.href='<?php
    echo $url_cancel
?>'">
<?php
}
if (isset($url_back)) { ?>
      <input id="back_editor" value="Back" type="button" name='cancel' class="ui-state-default ui-corner-all" onclick="window.location.href='<?php
    echo $url_back
?>'">
<?php
} ?>
    </td>
  </tr>
  <?php
echo safe_webtableclose() ?>
  <!-- </form> --> 

<script src="/SAFe/js/editor_common.js" type="text/javascript"></script>
<script type='text/javascript'>
$('.CodeMirror').css({
  "width":"<?php
echo $width
?>",
  "min-width":"<?php
echo $width
?>",
  "max-width":"<?php
echo $width
?>",
   "height":"<?php
	   echo $height
	   ?>",
  "min-height":"<?php
echo $min_height
?>"
});
<?php
if ($min_height == "0px")
{
    $overflow_y ="auto";
}else{
    $overflow_y ="hidden";
}
?>
$('.CodeMirror-scroll').css({
	"height":"<?php
		   echo $height
		   ?>",
    "overflow-y":"<?php echo $overflow_y;?>",
    "overflow-x":"auto"
});
// Create our own load/save function
  function editorLoad(){
  }
  function editorSave(){
    var data=$.base64.encode(editor.getValue());
    var editorSaveFileReq = $.ajax( {
      type : 'POST',
        url : '<?php
echo $url_save
?>',
        //processData : false,
        data :   { "data": data},
        contentType : "application/x-www-form-urlencoded"
        //accepts : {"*":"*/*"}
        //contentType : "text/xml; charset=utf-8"
    });
    editorSaveFileReq.done(function(data0){
      var obj = $.parseJSON(editorSaveFileReq.responseText);
      if(obj.result == "OK")
        window.location.href=obj.redirect;
      else
    	  safe_message_box('Save Error',safe_message_style(obj.message,'alert'));
    });
    editorSaveFileReq.fail(function(data0){
    	safe_message_box('Save Error',safe_message_style('Save FAILED','alert'));
    });   
  }
</script>

==> nsc-2.1.6-40-GA.update.tgz: var/webconfig/SAFe/application/views/safe_texteditor.php <==
<?php
/** vim: set tabstop=4 softtabstop=4 shiftwidth=4 textwidth=80 smarttab expandtab: **/
/** coding: utf-8: **/
/*
 * Copyright (C) 2012  Sangoma Technologies Corp.
 * All Rights Reserved.
 *
 * Author(s)
 * your name <your_name@sangoma.com>
 *
 * This code is Sangoma Technologies Confidential Property.
 * Use of and access to this code is covered by a previously executed
 * non-disclosure agreement between Sangoma Technologies and the Recipient.
 * This code is being supplied for evaluation purposes only and is not to be
 * used for any other purpose.
*/
?>
<!-- CodeMirror CSS-->
<link rel="stylesheet" href="/SAFe/js/codemirror/lib/codemirror.css">
<!-- CodeMirror theme -->

<!-- CodeMirror extra CSS -->
<link rel="stylesheet" href="/SAFe/js/codemirror/mode/diff/diff.css">
<link rel="stylesheet" href="/SAFe/js/codemirror/mode/markdown/markdown.css">
<link rel="stylesheet" href="/SAFe/js/codemirror/mode/tiddlywiki/tiddlywiki.css">
<!-- CodeMirror itself -->
<script src="/SAFe/js/codemirror/lib/codemirror.js" type="text/javascript"></script>
<script src="/SAFe/js/jquery/jquery.base64.js" type="text/javascript"></script>
<!-- CodeMirror Modes -->
<?php

$min_height = '0px';

if (!isset($height)) $height = "500px";
if (!isset($width)) $width = "100%";
if (!isset($min_height)) $min_height = $height;
if (isset($text_mode)) {
?>
  <script src="/SAFe/js/codemirror/mode/<?php
    echo $text_mode ?>/<?php
    echo $text_mode ?>.js" type="text/javascript"></script>
<?php
}
?>
  <?php
echo safe_webtabletitleopen($table_title, '100%', '') ?>
  <tr>
    <td>
    <?php 
    if($form){
        ?>
        <div style="height:30px">
        <form name="obj_data"> 
        <?php 
        foreach($form as $key => $value){
        ?>
            <label class="CodeMirror-gutter-text"><?php echo $value['label'];?></label>
            <input type="<?php echo $value['type'];?>" name="<?php echo $value['field'];?>" value="<?php echo $value['default'];?>" size="<?php echo $value['size'];?>" id="<?php echo $value['field'];?>" >
            <br>
        <?php 
        }
        ?>
        </form>
        </div> 
        <?php 
    }
    ?>
    <div id="#editorContainer" style="width:<?php
echo $width
?>; display: inline-block; border: 1px solid black;">
    
    <div style="display:inline-block; width:<?php
echo $width
?>; min-height:<?php
echo $min_height
?>;">
          
          <textarea class="editorWidth" id="editorTextArea" name="editor" style="display:none;"><?php
echo $editor_data
?></textarea> 
        </div>
      </div>
    </td>
  </tr>
  <tr>
    <td class='mytablelegend' colspan='%s' align='center'>
<?php
if (isset($url_save)) { ?>
      <input id="editorSaveButton" value="Save" type="button" name='save' class="ui-state-default ui-corner-all">
<?php
}
if (isset($url_cancel)) { ?>
      <input id="cancel_editor" value="Cancel" type="button" name='cancel' class="ui-state-default ui-corner-all" onclick="window.location.href='<?php
    echo $url_cancel
?>'">
<?php
}
if (isset($url_back)) { ?>
      <input id="back_editor" value="Back" type="button" name='cancel' class="ui-state-default ui-corner-all" onclick="window.location.href='<?php
    echo $url_back
?>'">
<?php
} ?>
    </td>
  </tr>
  <?php
echo safe_webtableclose() ?>
  <!-- </form> --> 

<script src="/SAFe/js/editor_common.js" type="text/javascript"></script>
<script type='text/javascript'>
$('.CodeMirror').css({
  "width":"<?php
echo $width
?>",
  "min-width":"<?php
echo $width
?>",
  "max-width":"<?php
echo $width
?>",
   "height":"<?php
	   echo $height
	   ?>",
  "min-height":"<?php
echo $min_height
?>"
});
<?php
if ($min_height == "0px")
{
    $overflow_y ="auto";
}else{
    $overflow_y ="hidden";
}
?>
$('.CodeMirror-scroll').css({
	"height":"<?php
		   echo $height
		   ?>",
    "overflow-y":"<?php echo $overflow_y;?>",
    "overflow-x":"auto"
});
// Create our own load/save function
  function editorLoad(){
  }
  function editorSave(){
    var post_data = new Array();
    var data=$.base64.encode(editor.getValue());
    var forms = $('form[name="obj_data"]');
	if (forms.length>0){
		post_data = $(forms[0]).serializeArray();
	}
	post_data.push({'name':'data' ,'value': data });
    var editorSaveFileReq = $.ajax( {
      type : 'POST',
        url : '<?php
echo $url_save
?>',
        //processData : false,
        data :   post_data,
        contentType : "application/x-www-form-urlencoded"
        //accepts : {"*":"*/*"}
        //contentType : "text/xml; charset=utf-8"
    });
    editorSaveFileReq.done(function(data0){
      var obj = $.parseJSON(editorSaveFileReq.responseText);
      if(obj.result == "OK")
        window.location.href=obj.redirect;
      else
    	  safe_message_box('Save Error',safe_message_style(obj.message,'alert'));
    });
    editorSaveFileReq.fail(function(data0){
    	safe_message_box('Save Error',safe_message_style('Save FAILED','alert'));
    });   
  }
</script>
